"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable:max-classes-per-file */
var path = require('path');
var fs = require('fs');
var generateComponent = require("./react-content").generateComponent;
var testContent = require('./test-content');
exports.generate = function (_a) {
    var fileSystem = _a.fileSystem, formatter = _a.formatter, ide = _a.ide, project = _a.project, settings = _a.settings;
    var editor = ide.getEditor();
    var inputText = editor.getText();
    var cursorPosition = editor.getCursorPosition();
    // console.log(`Searching from line ${cursorPosition.line} char ${cursorPosition.column}`);
    var result = generateComponent(inputText, cursorPosition, settings.sourcePath);
    result.matchWith({
        Error: function (_a) {
            var value = _a.value;
            return ide.log("Component generation failed: " + value);
        },
        Ok: function (_a) {
            var value = _a.value;
            var componentDetails = project.componentDetails(value.componentName);
            fileSystem.createComponent(componentDetails);
            if (value.changesToCaller) {
                value.changesToCaller.forEach(function (change, ix) {
                    // editor.setCursorScreenPosition(
                    //   { row: change.lineNumber + ix - 1, column: 0 });
                    // editor.insertNewline();
                    // editor.moveUp(1);
                    editor.insertText({ line: change.lineNumber + ix - 1, column: 0 }, change.content);
                    // editor.insertText(change.content);
                });
            }
            ide.open(componentDetails.componentPath).then(function (newEditor) {
                var formattedContent = formatter.format(value.content, componentDetails.componentPath);
                newEditor.setText(formattedContent);
            });
        },
    });
};
exports.tests = function (_a) {
    var fileSystem = _a.fileSystem, formatter = _a.formatter, ide = _a.ide, project = _a.project, settings = _a.settings;
    var activeEditor = ide.getEditor();
    var inputFilePath = activeEditor.getFilePath();
    var inputText = activeEditor.getText();
    var sourceFileWithinProject = project.fullPathToProjectPath(inputFilePath);
    if (!sourceFileWithinProject.startsWith(project.srcInsideProject)) {
        throw new Error("Source file " + sourceFileWithinProject + " not inside src folder " + project.srcInsideProject);
    }
    var testFilePath = path.join(settings.projectRoot, project.sourceFileWPToTestFileWP(sourceFileWithinProject));
    var inputModulePath = project.sourceFileToModulePath(inputFilePath);
    fileSystem.ensureFileExists(testFilePath);
    ide.open(testFilePath).then(function (editor) {
        var existingText = editor.getText();
        // initModulePaths(this.config.projectRoot);
        var generatedTests = testContent.generate(inputText, existingText, inputModulePath);
        var formattedContent = formatter.format(generatedTests.content, testFilePath);
        editor.setText(formattedContent);
    })
        .catch(function (e) {
        ide.log("Failed to open test file " + testFilePath + ": " + e);
    });
};
exports.switchFiles = function (_a) {
    var fileSystem = _a.fileSystem, formatter = _a.formatter, ide = _a.ide, project = _a.project, settings = _a.settings;
    var currentFilePath = ide.getEditor().getFilePath();
    var isCurrentFileTest = project.isPathTestFile(currentFilePath);
    if (isCurrentFileTest) {
        var sourceFilePath = project.testFileToSourceFile(currentFilePath);
        if (fs.existsSync(sourceFilePath)) {
            ide.open(sourceFilePath);
        }
        else {
            ide.log("The source file " + sourceFilePath + " doesn't seem to exist :(");
        }
    }
    else {
        var testFilePath = project.sourceFileToTestFile(currentFilePath);
        if (fs.existsSync(testFilePath)) {
            ide.open(testFilePath);
        }
        else {
            // TODO We could generate here
            ide.log("The test file " + testFilePath + " doesn't seem to exist :(");
        }
    }
};
//# sourceMappingURL=actions.js.map